@@ -45,6 +45,10 @@ function(b,c,n,conf.level)
        }
       }
   }
-  c(ll,ul)
+   cint <- c(ll, ul)
+   attr(cint, "conf.level") <- conf.level
+   rval <- list(conf.int = cint)
+   class(rval) <- "htest"
+   return(rval)
 }
 
